@@ -57,6 +57,8 @@
 #include <QtCore/private/qurl_p.h>
 #include <QtNetwork/private/qtldurl_p.h>
 
+QRegularExpression removeRuleCheck = QRegularExpression(QSL("\\s*remove\\s*:\\s*true\\s*;\\s*"));
+
 static QString getTopLevelDomain(const QUrl &url)
 {
     // QUrl::topLevelDomain() was removed in Qt6.
@@ -164,6 +166,11 @@ void AdBlockRule::setFilter(const QString &filter)
     parseFilter();
 }
 
+bool AdBlockRule::isRemoveRule() const
+{
+    return m_type == RemoveRule;
+}
+
 bool AdBlockRule::isCssRule() const
 {
     return m_type == CssRule;
@@ -219,6 +226,16 @@ void AdBlockRule::setEnabled(bool enabled)
     m_isEnabled = enabled;
 }
 
+bool AdBlockRule::isRewrite() const
+{
+    return m_rewriteTarget.isEmpty();
+}
+
+QUrl AdBlockRule::rewriteUrl() const
+{
+    return m_rewriteTarget;
+}
+
 bool AdBlockRule::isSlow() const
 {
     return m_regExp != nullptr;
@@ -231,6 +248,10 @@ bool AdBlockRule::isInternalDisabled() const
 
 bool AdBlockRule::urlMatch(const QUrl &url) const
 {
+    if (!isEnabled() || isInternalDisabled()) {
+        return false;
+    }
+
     if (!hasOption(DocumentOption) && !hasOption(ElementHideOption) && !hasOption(GenericHideOption) && !hasOption(GenericBlockOption)) {
         return false;
     }
@@ -358,6 +379,9 @@ bool AdBlockRule::matchType(const QWebEngineUrlRequestInfo &request) const
     case QWebEngineUrlRequestInfo::ResourceTypePluginResource:
         type = ObjectSubrequestOption;
         break;
+    case QWebEngineUrlRequestInfo::ResourceTypeWebSocket:
+        type = WebSocketOption;
+        break;
     case QWebEngineUrlRequestInfo::ResourceTypeSubResource:
     case QWebEngineUrlRequestInfo::ResourceTypeWorker:
     case QWebEngineUrlRequestInfo::ResourceTypeSharedWorker:
@@ -422,6 +446,30 @@ void AdBlockRule::parseFilter()
         return;
     }
 
+    /* Remove rule */
+    if (parsedLine.contains(QL1S("##"))) {
+        m_type = RemoveRule;
+
+        qsizetype beginRemoveRule = parsedLine.lastIndexOf(QL1S("{"));
+        qsizetype endRemoveRule = parsedLine.lastIndexOf(QL1S("}"));
+
+        if ((beginRemoveRule > 0) && (endRemoveRule > 0) && (beginRemoveRule < endRemoveRule)) {
+            qsizetype pos = parsedLine.indexOf(QL1C('#'));
+            // Domain restricted rule
+            if (!parsedLine.startsWith(QL1S("#"))) {
+                QString domains = parsedLine.left(pos);
+                parseDomains(domains, QL1C(','));
+            }
+
+            QString removeTest = parsedLine.sliced(beginRemoveRule + 1, (endRemoveRule - beginRemoveRule - 1));
+            auto result = removeRuleCheck.match(removeTest);
+            if (result.hasMatch()) {
+                m_matchString = parsedLine.sliced((pos + 2), (beginRemoveRule - (pos + 2)));
+                return;
+            }
+        }
+    }
+
     // CSS Element hiding rule
     if (parsedLine.contains(QL1S("##")) || parsedLine.contains(QL1S("#@#"))) {
         m_type = CssRule;
@@ -451,6 +499,12 @@ void AdBlockRule::parseFilter()
                 parseDomains(option.mid(7), QL1C('|'));
                 ++handledOptions;
             }
+            else if (option.startsWith(QL1S("rewrite="))) {
+                setOption(RewriteOption);
+                if (parseRewriteFilter(option.mid(8))) {
+                    ++handledOptions;
+                }
+            }
             else if (option == QL1S("match-case")) {
                 m_caseSensitivity = Qt::CaseSensitive;
                 ++handledOptions;
@@ -524,6 +578,10 @@ void AdBlockRule::parseFilter()
                 setOption(PopupOption);
                 ++handledOptions;
             }
+            else if (option == QL1S("websocket")) {
+                setOption(WebSocketOption);
+                ++handledOptions;
+            }
             else if (option == QL1S("document") && m_isException) {
                 setOption(DocumentOption);
                 ++handledOptions;
@@ -544,7 +602,12 @@ void AdBlockRule::parseFilter()
         }
 
         // If we don't handle all options, it's safer to just disable this rule
-        if (handledOptions != options.count()) {
+        if ((handledOptions != options.count())
+            /* Rewrite is only available with valid domain and is not available with thirdparty */
+            || (!hasOption(DomainRestrictedOption) && hasOption(RewriteOption))
+            || (hasOption(RewriteOption) && hasOption(ThirdPartyOption)
+            )
+        ) {
             m_isInternalDisabled = true;
             m_type = Invalid;
             return;
@@ -629,6 +692,34 @@ void AdBlockRule::parseFilter()
     m_matchString = parsedLine;
 }
 
+bool AdBlockRule::parseRewriteFilter(const QString& targetAddress)
+{
+    bool valid = false;
+
+    if (targetAddress.startsWith(QSL("abp-resource:"))) {
+        QStringList validValues = {
+            QSL("blank-js"),
+            QSL("blank-css"),
+            QSL("blank-html"),
+            QSL("blank-text"),
+            QSL("1x1-transparent-gif"),
+            QSL("2x2-transparent-png"),
+            QSL("3x2-transparent-png"),
+            QSL("32x32-transparent-png"),
+            QSL("blank-mp3"),
+            QSL("blank-mp4")
+        };
+        QString rewriteTarget = targetAddress.mid(13);
+
+        if (validValues.contains(rewriteTarget)) {
+            m_rewriteTarget = QUrl(targetAddress);
+            valid = true;
+        }
+    }
+
+    return valid;
+}
+
 void AdBlockRule::parseDomains(const QString &domains, const QChar &separator)
 {
     const QStringList domainsList = domains.split(separator, Qt::SkipEmptyParts);
