@@ -26,8 +26,10 @@ class QSettings;
 class FALKON_EXPORT DesktopFile
 {
 public:
-    explicit DesktopFile();
-    explicit DesktopFile(const QString &filePath);
+    DesktopFile();
+    explicit DesktopFile(const QString &fileName);
+
+    QString fileName() const;
 
     QString name() const;
     QString comment() const;
@@ -35,6 +37,8 @@ public:
     QString icon() const;
     QVariant value(const QString &key, bool localized = false) const;
 
+    bool tryExec() const;
+
 private:
     QSharedPointer<QSettings> m_settings;
 };
