@@ -15,7 +15,7 @@ TabManagerSettings::TabManagerSettings(TabManagerPlugin* plugin, QWidget *parent
     ui->checkBox->setChecked(m_plugin->asTabBarReplacement());
 
     connect(ui->buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
-    connect(ui->buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
+    connect(ui->buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
 }
 
 TabManagerSettings::~TabManagerSettings()
